userdir

package module
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 17, 2023 License: MIT Imports: 2 Imported by: 2

README

userdir

A small go library to get the user's config, data, home and cache directory.

It provides the base directories but also allows folders for organizational directories for apps or apps only to be made.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Userdir

type Userdir interface {
	Home() (string, error)
	Config() (string, error)
	Data() (string, error)
	Cache() (string, error)
}

func App

func App(appName string) Userdir

func Base

func Base() Userdir

func Org

func Org(orgName string, appName string) Userdir

Jump to